.. figure :: images/kinto-logo.svg
    :align: center

Kinto is a minimalist JSON storage service with synchronisation and sharing
abilities.

Table of content
================

.. toctree::
   :maxdepth: 1

   overview
   concepts
   community
   tutorials/index
   configuration/index
   api/index
   commandline
   kinto-admin
   faq
   troubleshooting
   changelog
   core/glossary
   core/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
